# -*- encoding: utf-8 -*-
#
# ** header v3.0
# This file is a part of the LinkAhead Project.
#
# Copyright (C) 2018 Research Group Biomedical Physics,
# Max-Planck-Institute for Dynamics and Self-Organization Göttingen
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# ** end header
#
"""Tests for the File class."""
from caosdb import File, Record, configure_connection
from caosdb.connection.mockup import MockUpServerConnection


def setup_module():
    assert File is not None
    configure_connection(url="unittests", username="testuser",
                         password_method="plain",
                         password="testpassword", timeout=200,
                         implementation=MockUpServerConnection)


def hat(obj, attr):
    assert hasattr(obj, attr)


def test_is_record():
    file_ = File()
    assert isinstance(file_, Record)


def test_instance_variable():
    file_ = File()
    hat(file_, "checksum")
    hat(file_, "file")
    hat(file_, "path")
    hat(file_, "size")


def test_role():
    file_ = File()
    assert file_.role == "File"


def test_ticket_237():
    """This is an ancient test which has been moved here from the integration
    test suite. It checks the basic functionality of the _wrap(function)"""

    f1 = File(
        name="name1",
        path="path1",
        file="file1")
    assert f1.name == "name1"
    assert f1.path == "path1"
    assert f1.file == "file1"

    f2 = File(name="name2")
    assert f2.name == "name2"
    assert f2.path is None
    assert f2.file is None

    f2._wrap(f1)

    assert f2.name == "name2"
    assert f2.path == "path1"
    assert f2.file == "file1"

    f2.path = "path2"
    f2.file = "file2"

    assert f2.name == "name2"
    assert f2.path == "path2"
    assert f2.file == "file2"

    assert f1.name == "name1"
    assert f1.path == "path1"
    assert f1.file == "file1"
